@@ -214,13 +214,13 @@ def get_session_name(user_access_key, vtiger_url, vtiger_username):
             print("Can not get Session name from Vtiger. Error occurred with Status", status)
 
 
-def trigger_workflow(workflow, event_type, data, service_url):
+def trigger_workflow(workflow, event_type, data, service_url, api_access_key):
     """ call API to trigger any workflow
         Required params: 1. workflow 2. event_type 3. data"""
 
-    headers = {'content_type': 'application/json'}
+    headers = {'content_type': 'application/json', 'Authorization': api_access_key}
 
-    endpoint = '{service_url}/api/v1/trigger_external_workflow'.format(service_url=service_url)
+    endpoint = '{service_url}/api/v1/trigger-external-workflow'.format(service_url=service_url)
 
     print(f"Endpoint: {endpoint}")
     print(f"Event Type: {event_type}")
@@ -350,17 +350,17 @@ def run_external_workflow(conf, task_id, vtiger_access):
                             # if event type = import/ manual then pass list
 
                             trigger_workflow(workflow, event_type, response.get('result'),
-                                             vtiger_access.get('service_url'))
+                                             vtiger_access.get('service_url'), vtiger_access.get('api_access_key'))
                         else:
                             trigger_workflow(workflow, event_type, response.get('result')[0],
-                                             vtiger_access.get('service_url'))
+                                             vtiger_access.get('service_url'), vtiger_access.get('api_access_key'))
             elif workflow and event_type and data:
                 # trigger without condition
                 if event_type == 'import' or event_type == 'manual':
                     list_of_data = [data]
-                    trigger_workflow(workflow, event_type, list_of_data, vtiger_access.get('service_url'))
+                    trigger_workflow(workflow, event_type, list_of_data, vtiger_access.get('service_url'), vtiger_access.get('api_access_key'))
                 else:
-                    trigger_workflow(workflow, event_type, data, vtiger_access.get('service_url'))
+                    trigger_workflow(workflow, event_type, data, vtiger_access.get('service_url'), vtiger_access.get('api_access_key'))
         else:
             print("external_workflow_config not found for task id:", task_id)
     else:
@@ -697,8 +697,9 @@ def add_delay_task(conf, task_id, vtiger_access):
             "delay_task_configs": delay_task_configs
         }
 
-    endpoint = '{service_url}/api/v1/add_delayed_data'.format(service_url=vtiger_access.get('service_url'))
-    headers = {'content_type': 'application/json'}
+    endpoint = '{service_url}/api/v1/add-delayed-data'.format(service_url=vtiger_access.get('service_url'))
+    headers = {'content_type': 'application/json', 'Authorization': vtiger_access.get('api_access_key')}
+
 
     response, status = invoke_http_request(endpoint, 'POST', headers, json_data=payload, timeout=61)
     print("response from add delayed task", response, "status", status)
